#include <QImage>
#include <QPainter>
/* QRgb je fakticky 32-bit unsigned int */
static unsigned char color_trig (const QRgb & color) {
  const unsigned q = ((color >> 16) & 0xFFu)
                   + ((color >>  8) & 0xFFu)
                   + ((color >>  0) & 0xFFu);
  return q < 0x180u ? 0u : 0xFFu;
}
static QImage Pixelize (const QImage & image) {
  QSize s = image.size();
  s.setWidth(s.width() / 3);
  QImage res (s, QImage::Format_ARGB32);
  for (int y=0; y<s.height(); y++) {
    // kopírujeme řádku po řádce
    const QRgb * src = reinterpret_cast<const QRgb *>(image.scanLine(y));
    QRgb * const dst = reinterpret_cast<QRgb * const>(res  .scanLine(y));
    for (int x=0; x<s.width(); x++) {   // a pixel po pixelu
      const int n = 3 * x;
      // podle pořadí pixelů ve sloupci (endianita ?) - bude asi nutno upravit
      QRgb c = (0xffu << 24) | (color_trig (src [n + 0]) << 16)
                             | (color_trig (src [n + 1]) <<  8)
                             | (color_trig (src [n + 2]) <<  0);
      dst [x] = c;
    }
  }
  return res;
}

int main (/*int argc, char** argv*/) {
  const QSize display (1620,2560);  // RGB plný obrázek
  QImage image (display, QImage::Format_ARGB32);
  const QColor fg (255,255,255, 255), bg (0,0,0, 255);          // neprůhledné
  image.fill (bg);       // bílá čára na černém pozadí
  QPainter painter (&image);
  painter.setPen (QPen (fg, 1));
  painter.setRenderHints(0);
//const QPoint b (0,0), e (display.width(), display.height());  // uhlopříčka
  const QPoint b (0,0), e (display.width(), display.width());   // čára 45 deg
  painter.drawLine (b, e);
  
  image           .save ("test1.bmp");;
  Pixelize (image).save ("test2.bmp");;
  return 0;
}
